@@ -1,14 +1,8 @@
-# Tests for top_levels function
-
-library(janitor)
-library(dplyr)
-context("top_levels()")
-
 fac <- factor(c("a", "b", "c", "d", "e", "f", "f"), levels = rev(letters[1:6]))
 fac_odd_lvls <- factor(fac, levels = rev(letters[1:5]))
 
 # more tests - group names and ordering - are in test-get-level-groups.R
-test_that("values are correct", {
+test_that("top_levels values are correct", {
   expect_equal(top_levels(fac)[[3]], c(3 / 7, 2 / 7, 2 / 7)) # default n = 2, num_levels = 6
   expect_equal(top_levels(fac)[[2]], c(3, 2, 2))
   expect_equal(top_levels(fac, 3)[[3]], c(4 / 7, 3 / 7)) # n = 3, num_levels = 6
@@ -19,7 +13,7 @@ test_that("values are correct", {
   expect_equal(top_levels(fac_odd_lvls, 1)[[3]], c(0.2, 0.6, 0.2))
 })
 
-test_that("missing levels are represented", {
+test_that("top_levels missing levels are represented", {
   x <- as.factor(letters[1:5])[1:3]
   expect_equal(top_levels(x)[[1]],
                structure(1:3, .Label = c("a, b", "c", "d, e"), class = "factor"))
@@ -28,7 +22,7 @@ test_that("missing levels are represented", {
 })
 
 
-test_that("NA results are treated appropriately", {
+test_that("top_levels NA results are treated appropriately", {
   fac_na <- fac
   fac_na[7] <- NA
   expect_equal(top_levels(fac_na)[[2]], rep(2, 3))
@@ -37,29 +31,29 @@ test_that("NA results are treated appropriately", {
   expect_equal(top_levels(fac_na, show_na = TRUE)[[4]], c(1 / 3, 1 / 3, 1 / 3, NA))
 })
 
-test_that("default n parameter works", {
+test_that("top_levels default n parameter works", {
   expect_equal(top_levels(fac), top_levels(fac, 2))
 })
 
-test_that("missing levels are treated appropriately", {
+test_that("top_levels missing levels are treated appropriately", {
   fac_missing_lvl <- fac
   fac_missing_lvl[2] <- NA
   expect_equal(top_levels(fac_missing_lvl)[[2]], c(3, 2, 1))
 })
 
-test_that("bad type inputs are handled", {
+test_that("top_levels bad type inputs are handled", {
   expect_error(top_levels(c(0, 1), "factor_vec is not of type 'factor'"))
   expect_error(top_levels(c("hi", "lo"), "factor_vec is not of type 'factor'"))
   expect_error(top_levels(mtcars, "factor_vec is not of type 'factor'"))
 })
 
-test_that("bad n value is handled", {
+test_that("top_levels bad n value is handled", {
   expect_error(top_levels(fac, 4))
   expect_error(top_levels(fac_odd_lvls, 3))
   expect_error(top_levels(fac, 0))
   expect_error(top_levels(factor(c("a", "b"))), "input factor variable must have at least 3 levels")
 })
 
-test_that("correct variable name assigned to first column of result", {
+test_that("top_levels correct variable name assigned to first column of result", {
   expect_equal(names(top_levels(fac))[1], "fac")
 })
